/*

Copyright (c) 2001 Michael Terry

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "color.h"

/* coupling is nothing more than a convenience struct, bundling a widget with 
   its original style. */

typedef struct coupling_def coupling;

struct coupling_def
{
	GtkWidget *widget;
	GdkColor color;
};

void color_diag_close (coupling *c, GtkColorSelectionDialog *colordiag)
{
	GtkStyle *style = gtk_style_copy (gtk_widget_get_style (c->widget));
	style->base[GTK_STATE_NORMAL] = c->color;
	
	gtk_widget_set_style (c->widget, style);
	gtk_widget_destroy (GTK_WIDGET(colordiag));
	g_free (c);
}

void color_diag_cancel (coupling *c, GtkWidget *button)
{
	GtkStyle *style = gtk_style_copy (gtk_widget_get_style (c->widget));
	style->base[GTK_STATE_NORMAL] = c->color;
	
	gtk_widget_set_style (c->widget, style);
	gdk_window_destroy (gtk_widget_get_parent_window (button));
	g_free (c);
}


void color_diag_ok (coupling *c, GtkWidget *button)
{
	save_pads();
	gdk_window_destroy (gtk_widget_get_parent_window (button));
	g_free (c);
}

void color_changed (coupling *c, GtkColorSelection *colorsel)
{
	GdkColor color;
	gdouble double_color[3];
	GtkStyle *style = gtk_style_copy(gtk_widget_get_style (c->widget));

	gtk_color_selection_get_color (colorsel, double_color);
	color.red = (guint16)(double_color[0]*65535.0);
	color.green = (guint16)(double_color[1]*65535.0);
	color.blue = (guint16)(double_color[2]*65535.0);
	
	style->base[GTK_STATE_NORMAL] = color;
	gtk_widget_set_style (c->widget, style);
}


void color_select (GtkWidget *widget)
{
	GtkWidget *color_diag;
	gdouble double_color[3];
	coupling *c = (coupling *) malloc (sizeof (coupling));

	c->widget = widget;
	c->color = (gtk_widget_get_style (widget))->base[GTK_STATE_NORMAL];

	color_diag = gtk_color_selection_dialog_new ("Choose background color.");
	double_color[0] = (guint32) c->color.red/65535.0;
	double_color[1] = (guint32) c->color.green/65535.0;
	double_color[2] = (guint32) c->color.blue/65535.0;
	gtk_color_selection_set_color (GTK_COLOR_SELECTION (GTK_COLOR_SELECTION_DIALOG(color_diag)->colorsel), double_color);

	gtk_signal_connect_object (GTK_OBJECT (color_diag), "destroy", GTK_SIGNAL_FUNC (color_diag_close), (gpointer) c);
	gtk_signal_connect_object (GTK_OBJECT (GTK_COLOR_SELECTION_DIALOG(color_diag)->cancel_button), "clicked", GTK_SIGNAL_FUNC (color_diag_cancel), (gpointer) c);
	gtk_signal_connect_object (GTK_OBJECT (GTK_COLOR_SELECTION_DIALOG(color_diag)->ok_button), "clicked", GTK_SIGNAL_FUNC (color_diag_ok), (gpointer) c);
	gtk_signal_connect_object (GTK_OBJECT (GTK_COLOR_SELECTION_DIALOG(color_diag)->colorsel), "color-changed", GTK_SIGNAL_FUNC (color_changed), (gpointer) c);
	gtk_widget_destroy (GTK_COLOR_SELECTION_DIALOG(color_diag)->help_button);

	gtk_widget_show (GTK_WIDGET (color_diag));
}







