/*

Copyright (c) 2001 Michael Terry

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "fio.h"
#include "xpad.h"
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

extern GtkWidget *create_pad(pad_info *info);

/* helper func to get textbox from window */
GtkText *get_text (GtkWindow *window)
{
	GList *kids = gtk_container_children (GTK_CONTAINER (window));
	
	do
	{
		if (strcmp (gtk_widget_get_name (kids->data), "GtkText") == 0)
			return kids->data;

		kids = kids->next;
	} while (kids != NULL);
	
	return NULL;
}

int set_file (const char *name, const char *value)
{
        FILE *file;
        char temp[1024];

        strcpy (temp, working_dir);
        strcat (temp, name);

        if ( (file = fopen (temp, "w")) == NULL)
        {
                fprintf (stderr, "Cannot open %s.\n", temp);
                return 1;
        }
         
        fputs (value, file);

        fclose (file);

	return 0;
}


int get_file (const char *name, char *value)
{
	char temp[1024];
        char c[2];
	FILE *file;
        
        strcpy (temp, working_dir);
        strcat (temp, name);
	strcpy (value, "");

	/* make sure it exists first */
	if ( (file = fopen (temp, "a")) == NULL)
	{
        	fprintf (stderr, "Cannot open %s.\n", temp);
		return 1;
	}

        if ( (file = freopen (temp, "r", file)) == NULL)
        {
        	fprintf (stderr, "Cannot open %s.\n", temp);
		return 1;
	}
	else
        {
	        c[1] = '\0';

	        while ( (c[0] = fgetc(file)) != EOF )
	                strcat (value, c);
	}

	fclose (file);

	return 0;
}
 
/* save contents and locations of all pads */
void save_pads ()
{                
        char window_file[MAX_FILE_SIZE] = "";
        pad_node *current = first_pad;
        gint x, y, height, width;
        int window_num = 0;
        gchar *content;
        char filename[1024];
	char temp[1024] = "";
	GdkColor color;

	if (first_pad == NULL) /* if no pads, blank file */
	{
		set_file (WINDOW_FILE, "");
		return;
	}

        do
        {
		GtkStyle *style = gtk_widget_get_style (GTK_WIDGET (get_text(GTK_WINDOW(current->window))));
		color = style->base[GTK_STATE_NORMAL];

                strcat (window_file, "WINDOW BEGIN\n");

                gdk_window_get_origin (current->window->window, &x, &y);
                gdk_window_get_size (current->window->window, &width, &height);
                sprintf (temp, "x %d\ny %d\nwidth %d\nheight %d\nback_red %d\nback_green %d\nback_blue %d\nfontname %s\n",
                             	x, y, width, height, color.red, color.green, color.blue, current->fontname);
		strcat (window_file, temp);
		strcpy (temp, "");

                content = gtk_editable_get_chars (GTK_EDITABLE (get_text(GTK_WINDOW(current->window))), 0, -1);
 		sprintf (filename, "window%d", window_num++);
		sprintf (temp, "content %s\n", filename);
		strcat (window_file, temp);
		strcpy (temp, "");
                set_file (filename, content);

                strcat (window_file, "WINDOW END\n");
 
                current = current->next;
                
                g_free (content);  
        } while ( current != NULL );
	
	set_file (WINDOW_FILE, window_file);
}

void load_pads ()
{
        char window_file[MAX_FILE_SIZE];
        pad_info info;
	char *item, *value;
	
	get_file (WINDOW_FILE, window_file);
        
	item = strtok (window_file, " ");
	value = strtok (NULL, "\n");
        
	if (item == NULL)
                create_pad (&DEFAULT_INFO);
        else 
                do
                {
                        if (strcmp (item, "WINDOW") == 0)
                        {
                                if (strcmp (value, "BEGIN") == 0)
                                        info = DEFAULT_INFO;
                                else
                                        create_pad (&info);
                        } 
                        else if (strcmp (item, "x") == 0)
                                info.x = atoi (value);   
                        else if (strcmp (item, "y") == 0)
                                info.y = atoi (value);
                        else if (strcmp (item, "width") == 0)
                                info.width = atoi (value);
                        else if (strcmp (item, "height") == 0)
                                info.height = atoi (value);
			else if (strcmp (item, "back_red") == 0)
				info.back_red = atoi (value);
			else if (strcmp (item, "back_green") == 0)
				info.back_green = atoi (value);
			else if (strcmp (item, "back_blue") == 0)
				info.back_blue = atoi (value);
			else if (strcmp (item, "fontname") == 0)
				info.fontname = value;
                        else if (strcmp (item, "content") == 0)
                                get_file (value, info.content);
                
			item = strtok (NULL, " ");
			value = strtok (NULL, "\n");
                 } while (item != NULL);
}



